@@ -56,7 +56,7 @@ sub lock {
         sleep 2;
         return 0 if ( $self->isLocked );
     }
-    unless ( open F, ">" . $self->_lock ) {
+    unless ( open F, ">", $self->_lock ) {
         $Lemonldap::NG::Common::Conf::msg .=
           "Unable to lock (" . $self->_lock . ") \n";
         return 0;
@@ -123,7 +123,6 @@ sub load {
         }
         binmode FILE;
         $f = join( '', <FILE> );
-        close FILE;
         eval { $ret = from_json( $f, { allow_nonref => 1 } ) };
         if ($@) {
             print STDERR "$@\n";
